pub trait Path {
type Out: ?Sized;
}Expand description
A Path object identifies a piece of the data store.
It can convert a borrow of the store’s data to a borrow of the piece it identifies.
Often, you won’t be working with the Path trait itself, but rather
the PathExt trait.
Path objects are mostly generated by #[derive(x_bow::Trackable)].
To hand-implement, see example code in src/impls/stdlib.
Required Associated Types